@@ -7,7 +7,7 @@ import yaml
 from typing import Optional, Dict
 
 EXPECTED_TF_CONFIG_FILE_NAMES = ["tdfconfig.yml", "tdfconfig.yaml", "validate_configs.yaml", "commit_configs.yaml"]
-TRANSFORM_API_URL = "https://web-api.prod.transformdata.io"
+TRANSFORM_API_URL = "https://api.transformdata.io"
 UPLOAD_MODE_VALIDATE = "validate"
 UPLOAD_MODE_COMMIT = "commit"
 # TODO: Return error response so this constant doesn't have to be passed to the CLI
